@@ -441,7 +441,7 @@ resizer.onResize = function ()
 	if (resizer.currentMode == "small" || resizer.currentMode == "mobile")
 	{
 		$('#portal-columns').after($("#FrontPageManagerLeft"));
-		Arnolfini.resizeImg("#FrontPageManagerRight .portletWrapper .portletCollection", "large");
+		Arnolfini.resizeImg("#FrontPageManagerRight .portletWrapper .portletCollection", "crop");
 		$('#FrontPageManagerLeft').masonry({columnWidth:189, gutterWidth:69, itemSelector:'.portletWrapper', isResizable:true, animate:false});
 		$('#portal-column-one').masonry({columnWidth:189, gutterWidth:69, itemSelector:'.portletWrapper', isResizable:true, animate:false});
 		$('#portal-column-two').masonry({columnWidth:189, gutterWidth:69, itemSelector:'.portletWrapper', isResizable:true, animate:false});
@@ -459,7 +459,7 @@ resizer.onResize = function ()
 			//Do nothing
 		}
 		
-		Arnolfini.resizeImg("#FrontPageManagerRight .portletWrapper .portletCollection", "portlet");
+		Arnolfini.resizeImg("#FrontPageManagerRight .portletWrapper .portletCollection", "crop");
 		
 		$("#FrontPageManagerRight").after($("#FrontPageManagerLeft"))
 	}
